package com.ozs.web.controller.shotschedule;

import com.ozs.common.core.domain.entity.SysDictData;
import com.ozs.common.utils.DictUtils;
import com.ozs.system.service.ISysDictDataService;
import com.ozs.system.service.ISysDictTypeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.Objects;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;

/**
 * @author wyy
 * @subject
 * @creat 2024/3/1
 */
@Configuration
@EnableScheduling
@EnableAsync
@Slf4j
public class ShotPictureExecutors {
    @Autowired
    private ISysDictDataService dictDataService;
    @Autowired
    private ISysDictTypeService iSysDictTypeService;
    @Autowired
    private TaskService taskService; //任务
    @Value("${shot.storeAddress}")
    private String storeAddress;

    /**
     * 处理非预警摄像头截图
     */
    @Async
    @Scheduled(fixedRate = 60000)
    public synchronized void handleNormalPicture() {
        List<SysDictData> dataList = DictUtils.getDictCache("shot_switch");
        if(CollectionUtils.isEmpty(dataList) || Objects.isNull(dataList.get(0))){
            dataList = iSysDictTypeService.selectDictDataByType("shot_switch");
            DictUtils.setDictCache("shot_switch",dataList);
        }
        List<SysDictData> addressDataList = DictUtils.getDictCache("shot_address");
        if(CollectionUtils.isEmpty(addressDataList) || Objects.isNull(addressDataList.get(0))){
            addressDataList = iSysDictTypeService.selectDictDataByType("shot_address");
            DictUtils.setDictCache("shot_address",addressDataList);
        }
        String address = addressDataList.get(0).getDictLabel();
        try {
            if(!CollectionUtils.isEmpty(dataList) && Objects.nonNull(dataList.get(0))){
                if (Boolean.parseBoolean(dataList.get(0).getDictLabel())) {
                    if(CollectionUtils.isEmpty(addressDataList) || Objects.isNull(addressDataList.get(0))){
                        address = storeAddress;
                    }
                        taskService.getNormalPicture(address);
                }
            }
        } catch (Exception e) {
            e.getMessage();
            log.error(e.getMessage());
        }
    }

    /**
     * 处理预警摄像头截图
     */
    @Async
    @Scheduled(fixedRate = 500)
    public synchronized void handleAlarmPicture() {
        List<SysDictData> dataList = DictUtils.getDictCache("shot_switch");
        if(CollectionUtils.isEmpty(dataList) || Objects.isNull(dataList.get(0))){
            dataList = iSysDictTypeService.selectDictDataByType("shot_switch");
            DictUtils.setDictCache("shot_switch",dataList);
        }
        List<SysDictData> addressDataList = DictUtils.getDictCache("shot_address");
        if(CollectionUtils.isEmpty(addressDataList) || Objects.isNull(addressDataList.get(0))){
            addressDataList = iSysDictTypeService.selectDictDataByType("shot_address");
            DictUtils.setDictCache("shot_address",addressDataList);
        }
        String address = addressDataList.get(0).getDictLabel();
        try {
            if(!CollectionUtils.isEmpty(dataList) && Objects.nonNull(dataList.get(0))){
                if (Boolean.parseBoolean(dataList.get(0).getDictLabel())) {
                    if(CollectionUtils.isEmpty(addressDataList) || Objects.isNull(addressDataList.get(0))){
                        address = storeAddress;
                    }
                    taskService.getAlarmPicture(address);
                }
            }
        } catch (Exception e) {
            e.getMessage();
            log.error(e.getMessage());
        }
    }
}
